@@ -1,5 +1,5 @@
 #define PCI_CONFIG_H
-#define PCI_ARCH_ARM64
+#define PCI_ARCH_OCTEON
 #define PCI_OS_OPENBSD
 #define PCI_HAVE_PM_OBSD_DEVICE
 #define PCI_PATH_OBSD_DEVICE "/dev/pci"
@@ -9,4 +9,4 @@
 #define PCI_PATH_IDS_DIR "/usr/local/share"
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
-#define PCILIB_VERSION "3.6.3"
+#define PCILIB_VERSION "3.6.4"
